@@ -1,5 +1,6 @@
 //extern crate base64;
 use reqwest::Result;
+use serde::{Deserialize, Serialize};
 use serde_json::Value;
 pub fn ascii_to_char(code: u8) -> char {
     std::char::from_u32(code as u32).unwrap_or('_')
@@ -55,7 +56,7 @@ enum Tcp {
     Ss,
     V2,
 }
-#[derive(Clone)]
+#[derive(Clone, Serialize, Deserialize)]
 pub struct Information {
     pub func: String,
     pub urls: String,
@@ -82,7 +83,7 @@ impl Information {
         output
     }
     pub fn running_json(&self) -> String {
-        if self.func == *"\"vmess\"" {
+        if self.func == *"vmess" {
             format!(
                 "{{
     \"inbounds\":[{{
@@ -94,26 +95,26 @@ impl Information {
         }}
     }}],
     \"outbounds\":[{{
-        \"protocol\":{},
+        \"protocol\":\"{}\",
         \"sendThrough\": \"0.0.0.0\",
         \"settings\":{{
             \"vnext\": [{{
-                \"address\": {},
+                \"address\": \"{}\",
                 \"port\":{},
                 \"users\":[{{
                     \"alterId\": {},
-                    \"id\":{}
+                    \"id\":\"{}\"
                 }}]
             }}]
         }},
         \"streamSettings\":{{
             \"dsSettings\": {{
-                \"path\": {}
+                \"path\": \"{}\"
             }},
             \"httpSettings\":{{
                 \"host\": [
                 ],
-                \"path\":{}
+                \"path\":\"{}\"
             }},
             \"kcpSettings\": {{
                 \"congestion\": false,
@@ -127,7 +128,7 @@ impl Information {
                 \"uplinkCapacity\": 5,
                 \"writeBufferSize\": 1
             }},
-            \"network\": {},
+            \"network\": \"{}\",
             \"quicSettings\":{{
                 \"header\": {{
                     \"type\":\"none\"
@@ -168,7 +169,7 @@ impl Information {
             \"wsSettings\" :{{
                 \"headers\" :{{
                 }},
-                \"path\":{}
+                \"path\":\"{}\"
             }},
             \"xtlsSettings\":{{
                 \"allowInsecure\":true,
@@ -200,8 +201,8 @@ impl Information {
 }}",
                 self.func,
                 self.add,
-                remove_quotation(self.port.clone()),
-                remove_quotation(self.aid.clone()),
+                self.port.clone(),
+                self.aid.clone(),
                 self.id,
                 self.path,
                 self.path,
@@ -329,12 +330,12 @@ impl Information {
             \"settings\": {{
                 \"servers\" :[
                     {{
-                        \"address\":{},
+                        \"address\":\"{}\",
                         \"email\": \"\",
                         \"level\": 0,
-                        \"method\": {},
+                        \"method\": \"{}\",
                         \"ota\":false,
-                        \"password\":{},
+                        \"password\":\"{}\",
                         \"port\":{}
                     }}
                 ]
@@ -424,21 +425,21 @@ impl Information {
                 self.add,
                 self.net,
                 self.id,
-                remove_quotation(self.port.clone())
+                self.port.clone()
             )
         }
     }
     fn get_the_link(&self) -> String {
         let mut temp = String::new();
-        if self.func == *"\"vmess\"" {
+        if self.func == *"vmess" {
             temp.push_str(&format!(
                 "vmess://{}:{}-{}@{}:{}/#{}",
-                &remove_quotation(self.net.clone()),
-                &remove_quotation(self.id.clone()),
-                &remove_quotation(self.aid.clone()),
-                &remove_quotation(self.add.clone()),
-                &remove_quotation(self.port.clone()),
-                &remove_quotation(self.ps.clone())
+                self.net.clone(),
+                self.id.clone(),
+                self.aid.clone(),
+                self.add.clone(),
+                self.port.clone(),
+                self.ps.clone()
             ))
         } else {
             temp = self.urls.clone();
@@ -448,21 +449,21 @@ impl Information {
     pub fn get_the_json_node(&self) -> String {
         format!(
             "{{
-    \"func\":{},
-    \"url\":\"{}\",
-    \"add\":{},
-    \"aid\":{},
-    \"host\":{},
-    \"id\":{},
-    \"net\":{},
-    \"path\":{},
-    \"port\":{},
-    \"ps\":{},
-    \"tls\":{},
-    \"type\":{}
+    \"urls\":\"{}\",
+    \"func\":\"{}\",
+    \"add\":\"{}\",
+    \"aid\":\"{}\",
+    \"host\":\"{}\",
+    \"id\":\"{}\",
+    \"net\":\"{}\",
+    \"path\":\"{}\",
+    \"port\":\"{}\",
+    \"ps\":\"{}\",
+    \"tls\":\"{}\",
+    \"typpe\":\"{}\"
 }},\n",
-            self.func,
             self.urls,
+            self.func,
             self.add,
             self.aid,
             self.host,
@@ -496,31 +497,31 @@ impl Information {
                 let header2 = ascii_to_string2(base64::decode(header.as_bytes()).unwrap());
                 // 通过分号切开两个内容
                 let header3: Vec<&str> = header2.split(':').collect();
-                let net = format!("\"{}\"", header3[0]);
-                let id = format!("\"{}\"", header3[1]);
+                let net = header3[0].to_string();
+                let id = header3[1].to_string();
 
                 let first_temp = first[1].to_string();
                 let second: Vec<&str> = first_temp.split('#').collect();
                 let ps0 = urlencoding::decode(second[1]).unwrap();
-                let ps = format!("\"{}\"", ps0);
+                let ps = format!("{}", ps0);
 
                 let second_temp = second[0].to_string();
                 let third: Vec<&str> = second_temp.split(':').collect();
-                let add = format!("\"{}\"", third[0]);
-                let port = format!("\"{}\"", third[1]);
+                let add = third[0].to_string();
+                let port = third[1].to_string();
                 Information {
                     urls: url,
-                    func: "\"ss\"".to_string(),
+                    func: "ss".to_string(),
                     add,
-                    aid: "\"unknown\"".to_string(),
-                    host: "\"\"".to_string(),
+                    aid: "unknown".to_string(),
+                    host: "".to_string(),
                     id,
                     net,
-                    path: "\"unknown\"".to_string(),
+                    path: "unknown".to_string(),
                     port,
                     ps,
-                    tls: "\"unknown\"".to_string(),
-                    typpe: "\"unknown\"".to_string(),
+                    tls: "unknown".to_string(),
+                    typpe: "unknown".to_string(),
                 }
             }
             Tcp::V2 => {
@@ -532,32 +533,32 @@ impl Information {
                         Information {
                             //company : input["add"].to_string(),
                             urls: url,
-                            func: "\"vmess\"".to_string(),
-                            add: input["add"].to_string(),
-                            aid: input["aid"].to_string(),
-                            host: input["host"].to_string(),
-                            id: input["id"].to_string(),
-                            net: input["net"].to_string(),
-                            path: input["path"].to_string(),
-                            port: input["port"].to_string(),
-                            ps: input["ps"].to_string(),
-                            tls: input["tls"].to_string(),
-                            typpe: input["type"].to_string(),
+                            func: "vmess".to_string(),
+                            add: remove_quotation(input["add"].to_string()),
+                            aid: remove_quotation(input["aid"].to_string()),
+                            host: remove_quotation(input["host"].to_string()),
+                            id: remove_quotation(input["id"].to_string()),
+                            net: remove_quotation(input["net"].to_string()),
+                            path: remove_quotation(input["path"].to_string()),
+                            port: remove_quotation(input["port"].to_string()),
+                            ps: remove_quotation(input["ps"].to_string()),
+                            tls: remove_quotation(input["tls"].to_string()),
+                            typpe: remove_quotation(input["type"].to_string()),
                         }
                     }
                     Err(_) => Information {
                         urls: url,
-                        func: "\"vmess\"".to_string(),
-                        add: "\"unknown\"".to_string(),
-                        aid: "\"unknown\"".to_string(),
-                        host: "\"unknown\"".to_string(),
-                        id: "\"unknown\"".to_string(),
-                        net: "\"unknown\"".to_string(),
-                        path: "\"unknown\"".to_string(),
-                        port: "\"unknown\"".to_string(),
-                        ps: "\"unknown\"".to_string(),
-                        tls: "\"unknown\"".to_string(),
-                        typpe: "\"unknown\"".to_string(),
+                        func: "vmess".to_string(),
+                        add: "unknown".to_string(),
+                        aid: "unknown".to_string(),
+                        host: "unknown".to_string(),
+                        id: "unknown".to_string(),
+                        net: "unknown".to_string(),
+                        path: "unknown".to_string(),
+                        port: "unknown".to_string(),
+                        ps: "unknown".to_string(),
+                        tls: "unknown".to_string(),
+                        typpe: "unknown".to_string(),
                     },
                 }
             }
